@@ -15,28 +15,24 @@ smooth.construct.mpi.smooth.spec<- function(object, data, knots)
   nk <- q+m+2 ## number of knots
   if (nk<=0) stop("k too small for m")
   x <- data[[object$term]]  ## the data
- # x.shift <- mean(x) # shift used to enhance stability
   xk <- knots[[object$term]] ## will be NULL if none supplied
   if (is.null(xk)) # space knots through data
-  { n<-length(x)
-    xk<-rep(0,q+m+2)
-    xk[(m+2):(q+1)]<-seq(min(x),max(x),length=q-m)
-    for (i in 1:(m+1)) {xk[i]<-xk[m+2]-(m+2-i)*(xk[m+3]-xk[m+2])}
-    for (i in (q+2):(q+m+2)) {xk[i]<-xk[q+1]+(i-q-1)*(xk[m+3]-xk[m+2])}
-  }
+     { n<-length(x)
+       xk<-rep(0,q+m+2)
+       xk[(m+2):(q+1)]<-seq(min(x),max(x),length=q-m)
+       for (i in 1:(m+1)) {xk[i]<-xk[m+2]-(m+2-i)*(xk[m+3]-xk[m+2])}
+       for (i in (q+2):(q+m+2)) {xk[i]<-xk[q+1]+(i-q-1)*(xk[m+3]-xk[m+2])}
+     }
   if (length(xk)!=nk) # right number of knots?
-  stop(paste("there should be ",nk," supplied knots"))
-#  x <- x - x.shift # basis stabilizing shift
-#  xk <- xk - x.shift # knots treated the same
+  stop(paste("there should be ", nk," supplied knots"))
   #  get model matrix-------------
   X1 <- splineDesign(xk,x,ord=m+2)
   # use matrix Sigma and remove the first column for the monotone smooth
-  Sig <- matrix(0,(q-1),(q-1))   # Define Matrix Sigma
+  Sig <- matrix(0,(q-1),(q-1))   
      # elements of matrix Sigma for increasing smooth
   for (i in 1:(q-1))  Sig[i,1:i]<-1
   X <- X1[,2:q]%*%Sig # model submatrix for the monotone term
-# X <- sweep(X,2,colMeans(X))
-  object$X<-X # the finished model matrix
+  object$X <- X # the finished model matrix
   object$P <- list()
   object$S <- list()
   object$Sigma <- Sig
@@ -46,7 +42,7 @@ smooth.construct.mpi.smooth.spec<- function(object, data, knots)
     object$P[[1]] <- P
     object$S[[1]] <- t(P)%*%P
   }
-  b<-rep(1,q-1) # define vector of 0's & 1's for model parameters identification
+  b <- rep(1,q-1) # define vector of 0's & 1's for model parameters identification
   object$p.ident <- b  
   object$rank <- ncol(object$X)-1  # penalty rank
   object$null.space.dim <- m+1  # dim. of unpenalized space
@@ -55,8 +51,6 @@ smooth.construct.mpi.smooth.spec<- function(object, data, knots)
   ## store "mpi" specific stuff ...
   object$knots <- xk;
   object$m <- m;
-#  object$x.shift <- x.shift
- 
   object$df<-ncol(object$X)     # maximum DoF (if unconstrained)
   class(object)<-"mpi.smooth"  # Give object a class
   object
@@ -69,18 +63,15 @@ smooth.construct.mpi.smooth.spec<- function(object, data, knots)
 Predict.matrix.mpi.smooth<-function(object,data)
 ## prediction method function for the `mpi' smooth class
 { x <- data[[object$term]]
- # x <- x - object$x.shift # stabilizing shift
   m <- object$m;     # spline order (3=cubic)
   q <- object$df + 1
-  xk<-object$knots    # knot locations
-  nk<-length(xk)      # number of knots
-  X1<-splineDesign(xk,x,ord=m+2)
-  Sig<-matrix(0,q,q)   # Define Matrix Sigma
-   # elements of matrix Sigma for increasing smooth
-  for (i in 1:q)  Sig[i,1:i]<-1
- # X<-X1[,2:ncol(X1)]%*%Sig 
-  X<-X1%*%Sig 
-# X <- sweep(X,2,colMeans(X)) # identifiability constraints for predict method
+  xk <- object$knots    # knot locations
+  nk <- length(xk)      # number of knots
+  X1 <- splineDesign(xk,x,ord=m+2)
+  Sig <- matrix(0,q,q)   # Define Matrix Sigma
+  # elements of matrix Sigma for increasing smooth
+  for (i in 1:q)  Sig[i,1:i] <- 1
+  X <- X1%*%Sig 
   X # return the prediction matrix
 }
 
@@ -100,19 +91,16 @@ smooth.construct.mpd.smooth.spec<- function(object, data, knots)
   nk <- q+m+2 ## number of knots
   if (nk<=0) stop("k too small for m")
   x <- data[[object$term]]  ## the data
-#  x.shift <- mean(x) # shift used to enhance stability
   xk <- knots[[object$term]] ## will be NULL if none supplied
   if (is.null(xk)) # space knots through data
-  { n<-length(x)
-    xk<-rep(0,q+m+2)
-    xk[(m+2):(q+1)]<-seq(min(x),max(x),length=q-m)
-    for (i in 1:(m+1)) {xk[i]<-xk[m+2]-(m+2-i)*(xk[m+3]-xk[m+2])}
-    for (i in (q+2):(q+m+2)) {xk[i]<-xk[q+1]+(i-q-1)*(xk[m+3]-xk[m+2])}
+     { n <- length(x)
+       xk <- rep(0,q+m+2)
+       xk[(m+2):(q+1)] <- seq(min(x),max(x),length=q-m)
+       for (i in 1:(m+1)) {xk[i] <- xk[m+2]-(m+2-i)*(xk[m+3]-xk[m+2])}
+       for (i in (q+2):(q+m+2)) {xk[i] <- xk[q+1]+(i-q-1)*(xk[m+3]-xk[m+2])}
   }
   if (length(xk)!=nk) # right number of knots?
   stop(paste("there should be ",nk," supplied knots"))
-#  x <- x - x.shift # basis stabilizing shift
-#  xk <- xk - x.shift # knots treated the same
   #  get model matrix-------------
   X1 <- splineDesign(xk,x,ord=m+2)
   # use matrix Sigma and remove the first column for the monotone smooth
@@ -120,7 +108,6 @@ smooth.construct.mpd.smooth.spec<- function(object, data, knots)
       # elements of matrix Sigma for decreasing smooth
   for (i in 1:(q-1))  Sig[i,1:i]<- -1
   X <- X1[,2:q]%*%Sig # model submatrix for the monotone term
-#  X <- sweep(X,2,colMeans(X))
   object$X<-X # the finished model matrix
   object$Sigma <- Sig
   object$P <- list()
@@ -140,8 +127,6 @@ smooth.construct.mpd.smooth.spec<- function(object, data, knots)
   ## store "mpd" specific stuff ...
   object$knots <- xk;
   object$m <- m;
-#  object$x.shift <- x.shift
- 
   object$df<-ncol(object$X)     # maximum DoF (if unconstrained)
   class(object)<-"mpd.smooth"  # Give object a class
   object
@@ -164,7 +149,6 @@ Predict.matrix.mpd.smooth<-function(object,data)
   Sig[,1] <- 1
   for (i in 2:q)  Sig[i,2:i]<- -1
   X <- X1%*%Sig 
- # X <- sweep(X,2,colMeans(X))
   X # return the prediction matrix
 }
 
@@ -190,19 +174,16 @@ smooth.construct.mdcv.smooth.spec<- function(object, data, knots)
   nk <- q+m+2 ## number of knots
   if (nk<=0) stop("k too small for m")
   x <- data[[object$term]]  ## the data
-#  x.shift <- mean(x) # shift used to enhance stability
   xk <- knots[[object$term]] ## will be NULL if none supplied
   if (is.null(xk)) # space knots through data
-  { n<-length(x)
-    xk<-rep(0,q+m+2)
-    xk[(m+2):(q+1)]<-seq(min(x),max(x),length=q-m)
-    for (i in 1:(m+1)) {xk[i]<-xk[m+2]-(m+2-i)*(xk[m+3]-xk[m+2])}
-    for (i in (q+2):(q+m+2)) {xk[i]<-xk[q+1]+(i-q-1)*(xk[m+3]-xk[m+2])}
-  }
+     { n<-length(x)
+       xk<-rep(0,q+m+2)
+       xk[(m+2):(q+1)]<-seq(min(x),max(x),length=q-m)
+       for (i in 1:(m+1)) {xk[i]<-xk[m+2]-(m+2-i)*(xk[m+3]-xk[m+2])}
+       for (i in (q+2):(q+m+2)) {xk[i]<-xk[q+1]+(i-q-1)*(xk[m+3]-xk[m+2])}
+     }
   if (length(xk)!=nk) # right number of knots?
   stop(paste("there should be ",nk," supplied knots"))
-#  x <- x - x.shift # basis stabilizing shift
-#  xk <- xk - x.shift # knots treated the same
   #  get model matrix-------------
   X1 <- splineDesign(xk,x,ord=m+2)
   # use matrix Sigma and remove the first column for the monotone smooth
@@ -210,7 +191,6 @@ smooth.construct.mdcv.smooth.spec<- function(object, data, knots)
      # for monotone decreasing & concave smooth
   for (i in 1:(q-1)) Sig[i:(q-1),i]<--c(1:(q-i))
   X <- X1[,2:q]%*%Sig # model submatrix for the constrained term
-#  X <- sweep(X,2,colMeans(X))
   object$X<-X # the finished model matrix
   object$Sigma <- Sig
   object$P <- list()
@@ -232,8 +212,6 @@ smooth.construct.mdcv.smooth.spec<- function(object, data, knots)
   ## store "mdcv" specific stuff ...
   object$knots <- xk;
   object$m <- m;
-#  object$x.shift <- x.shift
- 
   object$df<-ncol(object$X)     # maximum DoF (if unconstrained)
   class(object)<-"mdcv.smooth"  # Give object a class
   object
@@ -258,7 +236,6 @@ Predict.matrix.mdcv.smooth<-function(object,data)
   Sig[,1] <- rep(1,q)
   Sig [2:q,2:q] <- Sig1 
   X <- X1%*%Sig 
-#  X <- sweep(X,2,colMeans(X))
   X # return the prediction matrix
 }
 
@@ -280,7 +257,6 @@ smooth.construct.mdcx.smooth.spec<- function(object, data, knots)
   nk <- q+m+2 ## number of knots
   if (nk<=0) stop("k too small for m")
   x <- data[[object$term]]  ## the data
-#  x.shift <- mean(x) # shift used to enhance stability
   xk <- knots[[object$term]] ## will be NULL if none supplied
   if (is.null(xk)) # space knots through data
   { n<-length(x)
@@ -291,8 +267,6 @@ smooth.construct.mdcx.smooth.spec<- function(object, data, knots)
   }
   if (length(xk)!=nk) # right number of knots?
   stop(paste("there should be ",nk," supplied knots"))
-#  x <- x - x.shift # basis stabilizing shift
-#  xk <- xk - x.shift # knots treated the same
   #  get model matrix-------------
   X1 <- splineDesign(xk,x,ord=m+2)
   # use matrix Sigma and remove the first column for the monotone smooth
@@ -304,7 +278,6 @@ smooth.construct.mdcx.smooth.spec<- function(object, data, knots)
          Sig[i,(q-i+1):(q-1)]<--c((i-1):1)
   }
   X <- X1[,2:q]%*%Sig # model submatrix for the constrained term
-#  X <- sweep(X,2,colMeans(X))
   object$X<-X # the finished model matrix
   object$Sigma <- Sig
   object$P <- list()
@@ -326,8 +299,6 @@ smooth.construct.mdcx.smooth.spec<- function(object, data, knots)
   ## store "mdcx" specific stuff ...
   object$knots <- xk;
   object$m <- m;
-#  object$x.shift <- x.shift
- 
   object$df<-ncol(object$X)     # maximum DoF (if unconstrained)
   class(object)<-"mdcx.smooth"  # Give object a class
   object
@@ -356,7 +327,6 @@ Predict.matrix.mdcx.smooth<-function(object,data)
   Sig[,1] <- rep(1,q)
   Sig [2:q,2:q] <- Sig1
   X <- X1%*%Sig 
- # X <- sweep(X,2,colMeans(X))
   X # return the prediction matrix
 }
 
@@ -380,7 +350,6 @@ smooth.construct.micv.smooth.spec<- function(object, data, knots)
   nk <- q+m+2 ## number of knots
   if (nk<=0) stop("k too small for m")
   x <- data[[object$term]]  ## the data
-#  x.shift <- mean(x) # shift used to enhance stability
   xk <- knots[[object$term]] ## will be NULL if none supplied
   if (is.null(xk)) # space knots through data
   { n<-length(x)
@@ -391,8 +360,6 @@ smooth.construct.micv.smooth.spec<- function(object, data, knots)
   }
   if (length(xk)!=nk) # right number of knots?
   stop(paste("there should be ",nk," supplied knots"))
-#  x <- x - x.shift # basis stabilizing shift
-#  xk <- xk - x.shift # knots treated the same
   #  get model matrix-------------
   X1 <- splineDesign(xk,x,ord=m+2)
   # use matrix Sigma and remove the first column for the monotone smooth
@@ -404,7 +371,6 @@ smooth.construct.micv.smooth.spec<- function(object, data, knots)
        Sig[i,(q-i+1):(q-1)]<-c((i-1):1)
   }
   X <- X1[,2:q]%*%Sig # model submatrix for the constrained term
-#  X <- sweep(X,2,colMeans(X))
   object$X<-X # the finished model matrix
   object$Sigma <- Sig
   object$P <- list()
@@ -426,8 +392,6 @@ smooth.construct.micv.smooth.spec<- function(object, data, knots)
   ## store "micv" specific stuff ...
   object$knots <- xk;
   object$m <- m;
-#  object$x.shift <- x.shift
- 
   object$df<-ncol(object$X)     # maximum DoF (if unconstrained)
   class(object)<-"micv.smooth"  # Give object a class
   object
@@ -456,7 +420,6 @@ Predict.matrix.micv.smooth<-function(object,data)
   Sig[,1] <- rep(1,q)
   Sig [2:q,2:q] <- Sig1
   X <- X1%*%Sig 
-#  X <- sweep(X,2,colMeans(X))
   X # return the prediction matrix
 }
 
@@ -472,13 +435,12 @@ smooth.construct.micx.smooth.spec<- function(object, data, knots)
   require(splines)
   m <- object$p.order[1]
   if (is.na(m)) m <- 2 ## default 
-  if (m<1) stop("silly m supplied")
+  if (m < 1) stop("silly m supplied")
   if (object$bs.dim<0) object$bs.dim <- 10 ## default
   q <- object$bs.dim 
   nk <- q+m+2 ## number of knots
   if (nk<=0) stop("k too small for m")
   x <- data[[object$term]]  ## the data
-#  x.shift <- mean(x) # shift used to enhance stability
   xk <- knots[[object$term]] ## will be NULL if none supplied
   if (is.null(xk)) # space knots through data
   { n<-length(x)
@@ -489,8 +451,6 @@ smooth.construct.micx.smooth.spec<- function(object, data, knots)
   }
   if (length(xk)!=nk) # right number of knots?
   stop(paste("there should be ",nk," supplied knots"))
-#  x <- x - x.shift # basis stabilizing shift
-#  xk <- xk - x.shift # knots treated the same
   #  get model matrix-------------
   X1 <- splineDesign(xk,x,ord=m+2)
   # use matrix Sigma and remove the first column for the monotone smooth
@@ -498,7 +458,6 @@ smooth.construct.micx.smooth.spec<- function(object, data, knots)
      # for monotone increasing & convex smooth
   for (i in 1:(q-1)) Sig[i:(q-1),i]<-c(1:(q-i))
   X <- X1[,2:q]%*%Sig # model submatrix for the constrained term
-#  X <- sweep(X,2,colMeans(X))
   object$X<-X # the finished model matrix
   object$Sigma <- Sig
   object$P <- list()
@@ -520,8 +479,6 @@ smooth.construct.micx.smooth.spec<- function(object, data, knots)
   ## store "micx" specific stuff ...
   object$knots <- xk;
   object$m <- m;
-#  object$x.shift <- x.shift
- 
   object$df<-ncol(object$X)     # maximum DoF (if unconstrained)
   class(object)<-"micx.smooth"  # Give object a class
   object
@@ -546,7 +503,6 @@ Predict.matrix.micx.smooth<-function(object,data)
   Sig[,1] <- rep(1,q)
   Sig [2:q,2:q] <- Sig1
   X <- X1%*%Sig 
-#  X <- sweep(X,2,colMeans(X))
   X # return the prediction matrix
 }
 
@@ -571,7 +527,6 @@ smooth.construct.cv.smooth.spec<- function(object, data, knots)
   nk <- q+m+2 ## number of knots
   if (nk<=0) stop("k too small for m")
   x <- data[[object$term]]  ## the data
-#  x.shift <- mean(x) # shift used to enhance stability
   xk <- knots[[object$term]] ## will be NULL if none supplied
   if (is.null(xk)) # space knots through data
   { n<-length(x)
@@ -582,8 +537,6 @@ smooth.construct.cv.smooth.spec<- function(object, data, knots)
   }
   if (length(xk)!=nk) # right number of knots?
   stop(paste("there should be ",nk," supplied knots"))
-#  x <- x - x.shift # basis stabilizing shift
-#  xk <- xk - x.shift # knots treated the same
   #  get model matrix-------------
   X1 <- splineDesign(xk,x,ord=m+2)
   # use matrix Sigma and remove the first column for the monotone smooth
@@ -592,7 +545,6 @@ smooth.construct.cv.smooth.spec<- function(object, data, knots)
   for (i in 2:(q-1)) Sig[i:(q-1),i]<--c(1:(q-i))
   
   X <- X1[,2:q]%*%Sig # model submatrix for the constrained term
-#  X <- sweep(X,2,colMeans(X))
   object$X<-X # the finished model matrix
   object$Sigma <- Sig
   object$P <- list()
@@ -614,8 +566,6 @@ smooth.construct.cv.smooth.spec<- function(object, data, knots)
   ## store "cv" specific stuff ...
   object$knots <- xk;
   object$m <- m;
-#  object$x.shift <- x.shift
- 
   object$df<-ncol(object$X)     # maximum DoF (if unconstrained)
   class(object)<-"cv.smooth"  # Give object a class
   object
@@ -640,7 +590,6 @@ Predict.matrix.cv.smooth<-function(object,data)
   Sig[,1] <- rep(1,q)
   Sig [2:q,2:q] <- Sig1 
   X <- X1%*%Sig 
-#  X <- sweep(X,2,colMeans(X))
   X # return the prediction matrix
 }
 
@@ -661,7 +610,6 @@ smooth.construct.cx.smooth.spec<- function(object, data, knots)
   nk <- q+m+2 ## number of knots
   if (nk<=0) stop("k too small for m")
   x <- data[[object$term]]  ## the data
-#  x.shift <- mean(x) # shift used to enhance stability
   xk <- knots[[object$term]] ## will be NULL if none supplied
   if (is.null(xk)) # space knots through data
   { n<-length(x)
@@ -672,8 +620,6 @@ smooth.construct.cx.smooth.spec<- function(object, data, knots)
   }
   if (length(xk)!=nk) # right number of knots?
   stop(paste("there should be ",nk," supplied knots"))
-#  x <- x - x.shift # basis stabilizing shift
-#  xk <- xk - x.shift # knots treated the same
   #  get model matrix-------------
   X1 <- splineDesign(xk,x,ord=m+2)
   # use matrix Sigma and remove the first column for the monotone smooth
@@ -682,7 +628,6 @@ smooth.construct.cx.smooth.spec<- function(object, data, knots)
   for (i in 2:(q-1)) Sig[i:(q-1),i]<- c(1:(q-i))
   
   X <- X1[,2:q]%*%Sig # model submatrix for the constrained term
-#  X <- sweep(X,2,colMeans(X))
   object$X<-X # the finished model matrix
   object$Sigma <- Sig
   object$P <- list()
@@ -704,8 +649,6 @@ smooth.construct.cx.smooth.spec<- function(object, data, knots)
   ## store "cx" specific stuff ...
   object$knots <- xk;
   object$m <- m;
-#  object$x.shift <- x.shift
- 
   object$df<-ncol(object$X)     # maximum DoF (if unconstrained)
   class(object)<-"cx.smooth"  # Give object a class
   object
@@ -730,7 +673,6 @@ Predict.matrix.cx.smooth<-function(object,data)
   Sig[,1] <- rep(1,q)
   Sig [2:q,2:q] <- Sig1 
   X <- X1%*%Sig 
-#  X <- sweep(X,2,colMeans(X))
   X # return the prediction matrix
 }
 
